@@ -1,8 +1,8 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: version.py 309 2006-04-14 21:00:54Z piotrek $'
+__revision__ = '$Id: version.py 739 2007-02-20 16:01:12Z piotrek $'
 
-# Copyright (c) 2005 Vasco Nunes
+# Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,8 +23,8 @@ __revision__ = '$Id: version.py 309 2006-04-14 21:00:54Z piotrek $'
 
 from gettext import gettext as _
 pname        = "Griffith"
-pversion     = "0.6.2"
-pauthor      = "Vasco Nunes <vasco.m.nunes@gmail.com>"
-pyear        = "2005-2006"
-pwebsite     = "http://griffith.vasconunes.net/"
+pversion     = "0.9.2"
+pauthor      = "Vasco Nunes, Piotr Ożarowski <griffith-private@lists.berlios.de>"
+pyear        = "2005-2007"
+pwebsite     = "http://griffith.berlios.de/"
 pdescription = _("Griffith is a film collection manager.")
