@@ -1,9 +1,9 @@
 #!/usr/bin/env python
-# -*- coding: ISO-8859-1 -*-
+# -*- coding: utf-8 -*-
 
-__revision__ = '$Id: $'
+__revision__ = '$Id: winsetup.py 739 2007-02-20 16:01:12Z piotrek $'
 
-# Copyright (c) 2005 Vasco Nunes
+# Copyright (c) 2005-2007 Vasco Nunes
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -21,12 +21,6 @@ __revision__ = '$Id: $'
 # You may use and distribute this software under the terms of the
 # GNU General Public License, version 2 or later
 
-
-# for build this on a win32 environment and becames with a standalone distribution 
-# a base python 2.4 for 2in32 instalation must be present
-# along with gtk+ development libraries
-# pywin32com extensions, reportlab module, pygtk for win32 and pysqlite-1.1.7.win32-py2.4 (current win32 distro install is using this pysqlite 3 version)
-
 import time
 import sys
 
@@ -50,38 +44,43 @@ from distutils.core import setup
 import glob
 import py2exe
 
-opts = { 
-    "py2exe": { 
-        "includes": "cairo,pangocairo,cgi,PIL,sqlite,pysqlite2,pango,atk,gobject,tempfile,csv,xml.dom,xml.dom.ext,xml.dom.minidom,xml.sax,threading,htmlentitydefs,adodb,zipfile,webbrowser,shutil,reportlab,reportlab.pdfgen,reportlab.pdfgen.canvas,reportlab.platypus,smtplib,win32com,winshell", 
-        "dist_dir": "dist", 
-    } 
-} 
+opts = {
+    "py2exe": {
+        "includes": "pygtk,cairo,pangocairo,cgi,PIL,pysqlite2,pysqlite2.*,pango,atk,gobject,tempfile,csv,xml.dom,xml.dom.ext,xml.dom.minidom,xml.sax,threading,htmlentitydefs,sqlalchemy,sqlalchemy.*,sqlalchemy.mods.*,sqlalchemy.databases.*,sqlalchemy.engine.*,sqlalchemy.ext.*,sqlalchemy.orm.*,zipfile,webbrowser,shutil,reportlab,reportlab.pdfgen,reportlab.pdfgen.canvas,reportlab.platypus,reportlab.pdfbase.ttfonts,smtplib,win32com,platform,winshell,psycopg2,MySQLdb,chardet,gzip",
+        "optimize": 2,
+		"dist_dir": "dist",
+    }
+}
 
 setup(
     name = "Griffith",
-    description = "Griffith",
-    version = "0.6.2",
-    console = [ 
-        { 
-            "script": "griffith", 
-            "icon_resources": [(1, "images\griffith.ico")] 
+    version = "0.9.2",
+	description = 'Griffith - A film manager',
+    author = 'Vasco Nunes/Piotr Ozarowski',
+    author_email = 'vasco.m.nunes@gmail.com',
+    url = 'http://griffith.berlios.de',
+    license = 'GPL',
+    console = [
+        {
+            "script": "griffith",
+            "icon_resources": [(1, "images\griffith.ico")]
         }],
 		options = opts,
 		data_files=[
 		("images",
 		glob.glob("data\\*.png")),
 		("images/export_templates",
-		glob.glob("data\\export_templates\\*.dtd")),
+		glob.glob("export_templates\\*.dtd")),
 		("images/export_templates/csv",
-		glob.glob("data\\export_templates\\csv\\*.*")),
+		glob.glob("export_templates\\csv\\*.*")),
 		("images/export_templates/xml",
-		glob.glob("data\\export_templates\\xml\\*.*")),
+		glob.glob("export_templates\\xml\\*.*")),
 		("images/export_templates/latex",
-		glob.glob("data\\export_templates\\latex\\*.*")),
+		glob.glob("export_templates\\latex\\*.*")),
 		("images/export_templates/html_table",
-		glob.glob("data\\export_templates\\html_table\\*.*")),
+		glob.glob("export_templates\\html_table\\*.*")),
 		("images/export_templates/html_tables",
-		glob.glob("data\\export_templates\\html_tables\\*.*")),
+		glob.glob("export_templates\\html_tables\\*.*")),
 		("glade",
 		glob.glob("glade\\*.*")),
 		("i18n/bg/LC_MESSAGES",
@@ -100,10 +99,18 @@ setup(
 		glob.glob("i18n\\pt\\LC_MESSAGES\\*.mo")),
 		("i18n/it/LC_MESSAGES",
 		glob.glob("i18n\\it\\LC_MESSAGES\\*.mo")),
+		("i18n/sv/LC_MESSAGES",
+		glob.glob("i18n\\sv\\LC_MESSAGES\\*.mo")),
+		("i18n/pt_BR/LC_MESSAGES",
+		glob.glob("i18n\\pt_BR\\LC_MESSAGES\\*.mo")),
+		("lib/plugins",
+		glob.glob("lib\\plugins\\*.*")),
 		("lib/plugins/export",
 		glob.glob("lib\\plugins\\export\\*.*")),
 		("lib/plugins/movie",
 		glob.glob("lib\\plugins\\movie\\*.*")),
+		("lib/plugins/imp",
+		glob.glob("lib\\plugins\\imp\\*.*")),
 		("images",
 		glob.glob("images\\*.png")),
 		("",
